summaryrefslogtreecommitdiffstats
path: root/juk/tagtransactionmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/tagtransactionmanager.h')
-rw-r--r--juk/tagtransactionmanager.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/juk/tagtransactionmanager.h b/juk/tagtransactionmanager.h
index ce39393f..85bfc0b7 100644
--- a/juk/tagtransactionmanager.h
+++ b/juk/tagtransactionmanager.h
@@ -33,7 +33,7 @@ class TagTransactionAtom
{
public:
/**
* Default constructor, for use by QValueList.
*/
TagTransactionAtom();
@@ -63,7 +63,7 @@ class TagTransactionAtom
/**
* Assignment operator. This operator takes ownership of the m_tag pointer,
* so the object being assigned from no longer has access to the tag. This
* function exists mainly for the benefit of QValueList.
*
* @param other The TagTransactionAtom to copy from.
* @return The TagTransactionAtom being assigned to.
@@ -89,7 +89,7 @@ class TagTransactionAtom
mutable Tag *m_tag;
};
-typedef QValueList<TagTransactionAtom> TagAlterationList;
+typedef TQValueList<TagTransactionAtom> TagAlterationList;
/**
* This class manages alterations of a group of PlaylistItem's FileHandles. What this
@@ -111,9 +111,9 @@ class TagTransactionManager : public QObject
/**
* Constructs a TagTransactionManager, owned by @p parent.
*
* @param parent The parent QWidget.
*/
- TagTransactionManager(QWidget *parent = 0);
+ TagTransactionManager(TQWidget *parent = 0);
/**
* Returns the global TagTransactionManager instance.
@@ -137,13 +137,13 @@ class TagTransactionManager : public QObject
* object doesn't have a decent copy constructor.
*
* @param tag The Tag to duplicate.
* @param fileName The filename to assign to the tag. If QString::null
* (the default) is passed, the filename of the existing tag is
* used.
* @bug Tag should have a correct copy ctor and assignment operator.
* @return The duplicate Tag.
*/
- static Tag *duplicateTag(const Tag *tag, const QString &fileName = QString::null);
+ static Tag *duplicateTag(const Tag *tag, const TQString &fileName = TQString::null);
/**
* Commits the changes to the PlaylistItems. It is important that the
@@ -188,11 +188,11 @@ class TagTransactionManager : public QObject
* Renames the file identified by @p from to have the name given by @p to,
* prompting the user to confirm if necessary.
*
* @param from QFileInfo with the filename of the original file.
* @param to QFileInfo with the new filename.
* @return true if no errors occurred, false otherwise.
*/
- bool renameFile(const QFileInfo &from, const QFileInfo &to) const;
+ bool renameFile(const TQFileInfo &from, const TQFileInfo &to) const;
/**
* Used internally by commit() and undo(). Performs the work of updating
@@ -33,7 +33,7 @@ class TagTransactionAtom
public:
/**
- * Default constructor, for use by QValueList.
+ * Default constructor, for use by TQValueList.
*/
TagTransactionAtom();
@@ -63,7 +63,7 @@ class TagTransactionAtom
* Assignment operator. This operator takes ownership of the m_tag pointer,
* so the object being assigned from no longer has access to the tag. This
- * function exists mainly for the benefit of QValueList.
+ * function exists mainly for the benefit of TQValueList.
*
* @param other The TagTransactionAtom to copy from.
@@ -111,9 +111,9 @@ class TagTransactionManager : public QObject
* Constructs a TagTransactionManager, owned by @p parent.
*
- * @param parent The parent QWidget.
+ * @param parent The parent TQWidget.
*/
@@ -137,13 +137,13 @@ class TagTransactionManager : public QObject
*
* @param tag The Tag to duplicate.
- * @param fileName The filename to assign to the tag. If QString::null
+ * @param fileName The filename to assign to the tag. If TQString::null
* (the default) is passed, the filename of the existing tag is
* used.
@@ -188,11 +188,11 @@ class TagTransactionManager : public QObject
* prompting the user to confirm if necessary.
*
- * @param from QFileInfo with the filename of the original file.
- * @param to QFileInfo with the new filename.
+ * @param from TQFileInfo with the filename of the original file.
+ * @param to TQFileInfo with the new filename.
* @return true if no errors occurred, false otherwise.
*/